package net.sergeych.crypto2

import com.ionspin.kotlin.crypto.generichash.GenericHash
import com.ionspin.kotlin.crypto.util.encodeToUByteArray
import org.komputing.khash.keccak.Keccak
import org.komputing.khash.keccak.KeccakParameter

@Suppress("unused")
enum class Hash(val perform: (UByteArray)->UByteArray) {
    Blake2b({ GenericHash.genericHash(it) }),
    Blake2b2l({ blake2b2l(it) }),
    Sha3_384({ Keccak.digest(it.asByteArray(), KeccakParameter.SHA3_384).asUByteArray()}),
    Sha3_256({ Keccak.digest(it.asByteArray(), KeccakParameter.SHA3_256).asUByteArray()}),
}

private val defaultSuffix1 = "All lay loads on a willing horse".encodeToUByteArray()
private val defaultSuffix2 = "A stitch in time saves nine".encodeToUByteArray()

fun blake2b(src: UByteArray): UByteArray = Hash.Blake2b.perform(src)
fun blake2b2l(src: UByteArray): UByteArray =
    blake2b(blake2b(src) + defaultSuffix1 + src)
fun blake2b3l(src: UByteArray): UByteArray = blake2b(blake2b2l(src) + defaultSuffix2 + src)
